ParameterizedComplexCombination
===============================

.. currentmodule:: pykeen.nn.combinations

.. autoclass:: ParameterizedComplexCombination
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ParameterizedComplexCombination.score_imag
      ~ParameterizedComplexCombination.score_real

   .. rubric:: Methods Documentation

   .. automethod:: score_imag
   .. automethod:: score_real
